==> nextcloud-app-calendar-1%3A1.7.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ast.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendariu",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Quiximos informate de que %s espublizó'l calendariu «%s»",
    "Cheers!" : "¡Salú!",
    "Too many redirects. Aborting ..." : "Milenta redireiciones. Albortando...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El sirvidor remotu nun mos dio accesu al calendariu (fallu HTTP {%s})",
    "Error connecting to remote server" : "Fallu coneutando col sirvidor remotu",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fallu solicitando'l recursu nel sirvidor remotu. Esto quiciabes tea venceyao o un desaxuste de certificaos",
    "Error requesting resource on remote server" : "Fallu solicitando'l recursu nel sirvidor remotu",
    "Individual" : "Individual",
    "Group" : "Grupu",
    "Resource" : "Recursu",
    "Room" : "Habitación",
    "Unknown" : "Desconocí­u",
    "Required" : "Riquíu",
    "Optional" : "Opcional",
    "Does not attend" : "Nun atiendi",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Tas nunca zona horaria desconocia  ({tz}), torna a UTC",
    "Please create a calendar first." : "Por favor, crea entantes un calendariu.",
    "New event" : "Eventu nuevu",
    "CalDAV address for clients" : "Direición CalDAV pa veceros",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Dalgunos eventos nesti calendariu tán francíos. Por favor, compruebe la consola JS pa más información.",
    "Share Calendar" : "Compartir calendariu",
    "Shared" : "Compartíu",
    "WebDAV address for subscriptions" : "Direición WebDAV pa soscripciones",
    "group" : "grupu",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Repeating" : "Repetición",
    "When shared show full event" : "Amosar l'eventu completu al compartir",
    "When shared show only busy" : "Amosar namás ocupáu al compartir",
    "When shared hide this event" : "Anubrir l'eventu al compartir",
    "Confirmed" : "Confirmáu",
    "Tentative" : "Tentativa",
    "Cancelled" : "Encaboxáu",
    "The event can not end before it starts." : "L'eventu nun pue finar enantes de qu'entame.",
    "Global" : "Global",
    "None" : "Dengún",
    "Every day" : "Caldía",
    "Every week" : "Cada selmana",
    "Every month" : "Cada mes",
    "Every year" : "Cada añu",
    "never" : "enxamás",
    "after" : "dempués",
    "At time of event" : "A la hora l'eventu",
    "5 minutes before" : "5 minutos enantes",
    "10 minutes before" : "10 minutos enantes",
    "15 minutes before" : "15 minutos enantes",
    "30 minutes before" : "30 minutos enantes",
    "1 hour before" : "1 hora enantes",
    "2 hours before" : "2 hores enantes",
    "Custom" : "Personalizáu",
    "Audio" : "Audiu",
    "Pop-up" : "Ventanu emerxente",
    "sec" : "seg",
    "min" : "mín.",
    "hours" : "hores",
    "days" : "díes",
    "week" : "selmana",
    "before" : "enantes",
    "start" : "entamu",
    "end" : "fin",
    "Editing reminders of unknown type not supported." : "Nun ta soportáu l'editar recordatorios de triba desconocida",
    "Week {number} of {year}" : "Selmana {number} del {year}",
    "{type} {time} before the event starts" : "{type} {time} enantes que l'enventu entame",
    "{type} {time} before the event ends" : "{type} {time} enantes que l'eventu fine",
    "{type} {time} after the event starts" : "{type} {time} dempués que l'eventu entame",
    "{type} {time} after the event ends" : "{type} {time} dempués que l'eventu fine",
    "{type} at the event's start" : "{type} al entamu l'eventu",
    "{type} at the event's end" : "{type} cuando l'enventu fine",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartíu por  {owner}",
    "Title of the Event" : "Títulu del eventu",
    "All day Event" : "Tol día",
    "Delete" : "Desaniciar",
    "Cancel" : "Encaboxar",
    "More ..." : "Más ...",
    "Create" : "Crear",
    "Update" : "Anovar",
    "Close" : "Zarrar",
    "Location" : "Llocalización",
    "Description" : "Descripción",
    "Event status" : "Estáu del eventu",
    "Visibility when sharing" : "Visibilida mientres compartes",
    "Export" : "Esportar",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Quiximos informate de que %s espublizó'l calendariu {boldstart}%s{boldend}.",
    "We wanted to inform you that %s has published the calendar %s." : "Quiximos informate de que %s espublizó'l calendariu %s.",
    "Day" : "Día",
    "Week" : "Selmana",
    "Month" : "Mes",
    "Today" : "Güei",
    "More" : "Más",
    "Edit" : "Editar",
    "Link" : "Enllaz",
    "iCal link" : "Enllaz iCal",
    "Download" : "Baxar",
    "can edit" : "pue editar",
    "Public access" : "Accesu públicu",
    "Send" : "Unviar",
    "New Calendar" : "Calendariu nuevu",
    "Name" : "Nome",
    "New Subscription" : "Nueva Soscripción",
    "Go back" : "Dir p'atrás",
    "Calendar does not exist" : "El calendariu nun esiste",
    "Edit event" : "Editar eventu",
    "Delete Event" : "Desaniciar Eventu",
    "Save Event" : "Guardar Eventu",
    "Time" : "Hora",
    "Type" : "Triba",
    "Relative" : "Relativu",
    "Absolute" : "Absolutu",
    "Repeat" : "Repitir",
    "times every" : "cada vegada",
    "Add" : "Amestar",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor amiesta'l to corréu nos axustes de la so cuenta p'amestar asistentes",
    "from" : "Dende",
    "to" : "hasta",
    "This event's repeating rule is not supported yet." : "Esta riegla de repetición d'eventos entá nun ta soportada.",
    "Support for advanced rules will be added with subsequent updates." : "Soporte pa riegles avanzaes va amestase con actualizaciones posteriores.",
    "Reset repeating rule" : "Reafitar repetición de regla",
    "Repeat every ..." : "Repitir acaldía ...",
    "end repeat ..." : "finar repetición ...",
    "times" : "vegaes",
    "Import Calendars" : "Importar Calendarios",
    "Import canceled" : "Desaniciar importación",
    "Analyzing calendar" : "Analizando calendariu",
    "The file contains objects incompatible with the selected calendar" : "El ficheru contién oxetos incompatibles col calendariu esbilláu",
    "New calendar" : "Calendariu nuevu",
    "File is empty" : "El ficheru ta baleru",
    "Import scheduled" : "Importar horariu",
    "%s shared the calendar <strong>%s</strong> with you" : "%s compartió'l calendariu <strong>%s</strong> contigo",
    "Publish URL" : "Espublizar URL",
    "Settings & import" : "Axustes ya importación",
    "Import calendar" : "Importar calendariu",
    "No Calendars selected for import" : "Nun s'esbilló nengún calendariu pa la importación",
    "Skip simple event editor" : "Saltar editor d'eventos simples",
    "Show week numbers" : "Amosar númberos de la selmana",
    "Primary CalDAV address" : "Direición de calendariu CalDAV primariu",
    "Subscribe" : "Soscribise"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A2.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ast.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendariu",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Quiximos informate de que %s espublizó'l calendariu «%s»",
    "Open »%s«" : "Abrir «%s»",
    "Cheers!" : "¡Salú!",
    "Today" : "Güei",
    "Day" : "Día",
    "Week" : "Selmana",
    "Month" : "Mes",
    "Download" : "Baxar",
    "Delete" : "Desaniciar",
    "Share link" : "Share link",
    "Share with users or groups" : "Compartir con usuarios y grupos",
    "can edit" : "pue editar",
    "New calendar" : "Calendariu nuevu",
    "Filename" : "Nome de ficheru",
    "Cancel" : "Encaboxar",
    "Automatic" : "Automáticu",
    "Show week numbers" : "Amosar númberos de la selmana",
    "Settings & import" : "Axustes ya importación",
    "Notification" : "Avisu",
    "Email" : "email",
    "Unknown" : "Desconozse",
    "All day" : "Tol día",
    "from" : "Dende",
    "to" : "hasta",
    "never" : "enxamás",
    "after" : "dempués",
    "Repeat" : "Repitir",
    "Monday" : "Llunes",
    "Summary" : "Sumariu",
    "More" : "Más",
    "Save" : "Guardar",
    "Update" : "Anovar",
    "Personal" : "Personal",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Activity" : "Actividá",
    "Close" : "Zarrar",
    "Anniversary" : "Aniversariu",
    "Week {number} of {year}" : "Selmana {number} del {year}",
    "Daily" : "Caldía",
    "Weekly" : "Selmanalmente",
    "When shared show full event" : "Amosar l'eventu completu al compartir",
    "When shared show only busy" : "Amosar namás ocupáu al compartir",
    "When shared hide this event" : "Anubrir l'eventu al compartir",
    "Location" : "Llocalización",
    "Description" : "Descripción",
    "Status" : "Estáu",
    "Confirmed" : "Confirmáu",
    "Tentative" : "Tentativa",
    "Cancelled" : "Encaboxáu",
    "Categories" : "Estayes",
    "Presentation" : "Presentación",
    "Office" : "Oficina",
    "Mail" : "Corréu",
    "Play" : "Reproducir",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");
